.. nxsconfigserver documentation master file, created by
   sphinx-quickstart on Wed Apr 20 15:10:35 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

=========
Contents:
=========

.. toctree::
   :maxdepth: 4

   nxsconfigserver

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
